@@ -7,12 +7,14 @@
 #pragma once
 #include "libkaichatwidgets_private_export.h"
 #include <KPageDialog>
-#include <QObject>
 class KAIChatConfigureGeneralWidget;
 class KAIChatConfigureInstancesWidget;
+class KAIChatConfigureFontWidget;
+class KAIChatConfigureSpellCheckingWidget;
 namespace TextAutoGenerateText
 {
 class TextAutoGenerateManager;
+class TextAutoGenerateTextConfigurePluginsWidget;
 }
 class LIBKAICHATWIDGETS_TESTS_EXPORT KAIChatConfigureSettingsDialog : public KPageDialog
 {
@@ -28,4 +30,7 @@ private:
     LIBKAICHATWIDGETS_NO_EXPORT void load();
     KAIChatConfigureGeneralWidget *const mConfigureGeneralWidget;
     KAIChatConfigureInstancesWidget *const mInstancesManagerWidget;
+    TextAutoGenerateText::TextAutoGenerateTextConfigurePluginsWidget *const mConfigurePluginsWidget;
+    KAIChatConfigureFontWidget *const mConfigureFontWidget;
+    KAIChatConfigureSpellCheckingWidget *const mConfigureSpellCheckingWidget;
 };
